# On x86 arch build RPM with this command:
#
# rpmbuild -ba SPEC/kernel-modules-connlimit.spec --target=i686
#
# You may define the kernel version to build for with:
#     --define "kernel <version>"

%define _libmoddir /lib/modules

%{!?kernel:%define kernel %(rpm -q kernel-devel --qf '%{RPMTAG_VERSION}-%{RPMTAG_RELEASE}\\n' | tail -1)}

%define _with_smp %(test -d %{_libmoddir}/%{kernel}smp/build && echo 1 || echo 0)

%define kversion %(echo "%{kernel}" | sed -e 's|-.*||')
%define krelease %(echo "%{kernel}" | sed -e 's|.*-||')

%define pversion 20051006
%define real_name ipt_connlimit
%define builddir  BUILD-connlimit
%define moduledir /kernel/net/ipv4/netfilter
%define includedir /build/include/linux/netfilter_ipv4

Summary: Linux module for connlimit.
Name:    kernel-modules-connlimit
Version: %(echo %{kernel} | sed 's@-@_@g')
Release: 0.%{pversion}.%{mysig}
License: GPL
Group:   System Environment/Kernel
URL:     http://www.netfilter.org/patch-o-matic/
Source0: http://ftp.netfilter.org/pub/patch-o-matic-ng/snapshot/patch-o-matic-ng-%{pversion}.tar.bz2
Patch0:  connlimit-2.6.9-RH.patch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
BuildRequires: kernel-devel
ExclusiveArch: i686 x86_64
Requires: kernel = %{kernel}
Obsoletes: kernel-modules-connlimit-2.6.9-11.EL

%description
Module connlimit for Linux 2.6.x kernel.

%package -n kernel-smp-modules-connlimit
Summary:  Linux SMP connlimit for Linux 2.6.x kernel.
Group:    System Environment/Kernel
Requires: kernel-smp = %{kernel}
Obsoletes: kernel-modules-connlimit-2.6.9-11.EL

%description -n kernel-smp-modules-connlimit
Module connlimit for Linux 2.6.x SMP kernel.

%prep
%setup -q -n patch-o-matic-ng-%{pversion}
cat <<EOF

Package version: %{version}
Package release: %{release}
For kernel: %{kernel}
For target: %{_target_cpu}
With SMP: %{_with_smp}

EOF

preparemodule() {
	# lets move source off the tree
	mkdir $1
	pushd $1
	cp -a ../patchlets/connlimit/linux/include/linux/netfilter_ipv4/%{real_name}.h .
	cp -a ../patchlets/connlimit/linux/net/ipv4/netfilter/%{real_name}.c .
	# ipt_connlimit.h is in the current directory
	perl -pi -e 's@<linux/netfilter_ipv4/(%{real_name}.h)>@"$1"@' %{real_name}.c
	# because RH changes in 2.6.9, we need a sligtly newer version of ipt_connlimit.c
%patch0 -p1 -b .RH
	# Makefile from http://www.redhat.com/docs/manuals/enterprise/RHEL-4-Manual/release-notes/as-x86/
	cat > Makefile <<EOF
obj-m := %{real_name}.o

KDIR  := /lib/modules/$2/build
PWD   := \$(shell pwd)

default:
	%{__make} -C \$(KDIR) SUBDIRS=\$(PWD) modules
	#%{__make} -C \$(KDIR) SUBDIRS=\$(PWD) ARCH="$(echo %{_target_cpu} | sed -e 's/\(i.86\|athlon\)/i386/')" modules
EOF
	popd
}

preparemodule %{builddir} %{kernel}
%if %{_with_smp}
  preparemodule %{builddir}-smp %{kernel}smp
%endif

%build
pushd %{builddir}
make
popd
%if %{_with_smp}
  pushd %{builddir}-smp
  make
  popd
%endif

%install
installmodule() {
	pushd $1
	DIR=$RPM_BUILD_ROOT%{_libmoddir}/$2/%{moduledir}
	mkdir -p $DIR
	install -m744 %{real_name}.ko $DIR
	DIR=$RPM_BUILD_ROOT%{_libmoddir}/$2/%{includedir}
	mkdir -p $DIR
	install -m644 %{real_name}.h $DIR
	popd
}

installmodule %{builddir} %{kernel}
%if %{_with_smp}
  installmodule %{builddir}-smp %{kernel}smp
%endif

%post -n kernel-modules-connlimit
/sbin/depmod -ae %{kernel} || :

%postun -n kernel-modules-connlimit
/sbin/depmod -ae %{kernel} || :

%post -n kernel-smp-modules-connlimit
/sbin/depmod -ae %{kernel}smp || :

%postun -n kernel-smp-modules-connlimit
/sbin/depmod -ae %{kernel}smp || :

%clean
%{__rm} -rf %{buildroot}

%files
%defattr(-, root, root)
%attr(0744,root,root) %{_libmoddir}/%{kernel}/%{moduledir}/%{real_name}.ko
%attr(0644,root,root) %{_libmoddir}/%{kernel}/%{includedir}/%{real_name}.h

%if %{_with_smp}
%files -n kernel-smp-modules-connlimit
%defattr(-, root, root)
%attr(0744,root,root) %{_libmoddir}/%{kernel}smp/%{moduledir}/%{real_name}.ko
%attr(0644,root,root) %{_libmoddir}/%{kernel}smp/%{includedir}/%{real_name}.h
%endif

%changelog
* Wed Nov 02 2005 Milan Kerslager <kerslage@linux.cz> 2.6.9_22.0.1.EL-0.20051006.ker.rhel4
- rebuild for kernel-2.6.9-22.0.1.EL

* Fri Oct 07 2005 Milan Kerslager <kerslage@linux.cz> 2.6.9_22.EL-5.20051006.ker.rhel4
- rebuild for RHEL4 U2 kernel

* Sun Jul 10 2005 Milan Kerslager <kerslage@linux.cz> 2.6.9_11.EL-5.20050702.ker.rhel4
- fix for SMP build

* Wed Jul 06 2005 Milan Kerslager <kerslage@linux.cz> 2.6.9_11.EL-4.20050702.ker.rhel4
- added Obsoletes (bothpackages) and Requires (non-smp package)
- build SMP package

* Wed Jul 06 2005 Milan Kerslager <kerslage@linux.cz> 2.6.9_11.EL-3.20050702.ker.rhel4
- renamed from kernel-modules-connlimit-%{kernel} to kernel-modules-connlimit
- fix Requires for SMP kernel
- added ExclusiveArch: i686

* Sun Jul 03 2005 Milan Kerslager <kerslage@linux.cz> 2.6.9-11.EL-20050702-1.ker.rhel4
- initial version
